==> docx4j-openxml-objects-8.3.10-sources.jar: org/docx4j/dml/CTTablePartStyle.java <==
/*
 *  Copyright 2007-2008, Plutext Pty Ltd.
 *   
 *  This file is part of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */


package org.docx4j.dml;

import javax.xml.bind.Unmarshaller;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.ppp.Child;


/**
 * <p>Java class for CT_TablePartStyle complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CT_TablePartStyle"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="tcTxStyle" type="{http://schemas.openxmlformats.org/drawingml/2006/main}CT_TableStyleTextStyle" minOccurs="0"/&gt;
 *         &lt;element name="tcStyle" type="{http://schemas.openxmlformats.org/drawingml/2006/main}CT_TableStyleCellStyle" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_TablePartStyle", propOrder = {
    "tcTxStyle",
    "tcStyle"
})
public class CTTablePartStyle implements Child
{

    protected CTTableStyleTextStyle tcTxStyle;
    protected CTTableStyleCellStyle tcStyle;
    @XmlTransient
    private Object parent;

    /**
     * Gets the value of the tcTxStyle property.
     * 
     * @return
     *     possible object is
     *     {@link CTTableStyleTextStyle }
     *     
     */
    public CTTableStyleTextStyle getTcTxStyle() {
        return tcTxStyle;
    }

    /**
     * Sets the value of the tcTxStyle property.
     * 
     * @param value
     *     allowed object is
     *     {@link CTTableStyleTextStyle }
     *     
     */
    public void setTcTxStyle(CTTableStyleTextStyle value) {
        this.tcTxStyle = value;
    }

    /**
     * Gets the value of the tcStyle property.
     * 
     * @return
     *     possible object is
     *     {@link CTTableStyleCellStyle }
     *     
     */
    public CTTableStyleCellStyle getTcStyle() {
        return tcStyle;
    }

    /**
     * Sets the value of the tcStyle property.
     * 
     * @param value
     *     allowed object is
     *     {@link CTTableStyleCellStyle }
     *     
     */
    public void setTcStyle(CTTableStyleCellStyle value) {
        this.tcStyle = value;
    }

    /**
     * Gets the parent object in the object tree representing the unmarshalled xml document.
     * 
     * @return
     *     The parent object.
     */
    public Object getParent() {
        return this.parent;
    }

    public void setParent(Object parent) {
        this.parent = parent;
    }

    /**
     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
     * 
     * @param parent
     *     The parent object in the object tree.
     * @param unmarshaller
     *     The unmarshaller that generated the instance.
     */
    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
        setParent(parent);
    }

}

==> docx4j-openxml-objects-11.5.3-sources.jar: org/docx4j/dml/CTTablePartStyle.java <==
/*
 *  Copyright 2007-2008, Plutext Pty Ltd.
 *   
 *  This file is part of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */


package org.docx4j.dml;

import jakarta.xml.bind.Unmarshaller;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlTransient;
import jakarta.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.ppp.Child;


/**
 * <p>Java class for CT_TablePartStyle complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CT_TablePartStyle"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="tcTxStyle" type="{http://schemas.openxmlformats.org/drawingml/2006/main}CT_TableStyleTextStyle" minOccurs="0"/&gt;
 *         &lt;element name="tcStyle" type="{http://schemas.openxmlformats.org/drawingml/2006/main}CT_TableStyleCellStyle" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_TablePartStyle", propOrder = {
    "tcTxStyle",
    "tcStyle"
})
public class CTTablePartStyle implements Child
{

    protected CTTableStyleTextStyle tcTxStyle;
    protected CTTableStyleCellStyle tcStyle;
    @XmlTransient
    private Object parent;

    /**
     * Gets the value of the tcTxStyle property.
     * 
     * @return
     *     possible object is
     *     {@link CTTableStyleTextStyle }
     *     
     */
    public CTTableStyleTextStyle getTcTxStyle() {
        return tcTxStyle;
    }

    /**
     * Sets the value of the tcTxStyle property.
     * 
     * @param value
     *     allowed object is
     *     {@link CTTableStyleTextStyle }
     *     
     */
    public void setTcTxStyle(CTTableStyleTextStyle value) {
        this.tcTxStyle = value;
    }

    /**
     * Gets the value of the tcStyle property.
     * 
     * @return
     *     possible object is
     *     {@link CTTableStyleCellStyle }
     *     
     */
    public CTTableStyleCellStyle getTcStyle() {
        return tcStyle;
    }

    /**
     * Sets the value of the tcStyle property.
     * 
     * @param value
     *     allowed object is
     *     {@link CTTableStyleCellStyle }
     *     
     */
    public void setTcStyle(CTTableStyleCellStyle value) {
        this.tcStyle = value;
    }

    /**
     * Gets the parent object in the object tree representing the unmarshalled xml document.
     * 
     * @return
     *     The parent object.
     */
    public Object getParent() {
        return this.parent;
    }

    public void setParent(Object parent) {
        this.parent = parent;
    }

    /**
     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
     * 
     * @param parent
     *     The parent object in the object tree.
     * @param unmarshaller
     *     The unmarshaller that generated the instance.
     */
    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
        setParent(parent);
    }

}
